@@ -17,8 +17,6 @@ GType gdk_cursor_type_get_type (void) G_GNUC_CONST;
 #define GDK_TYPE_CURSOR_TYPE (gdk_cursor_type_get_type ())
 
 /* enumerations from "gdkdevice.h" */
-GType gdk_extension_mode_get_type (void) G_GNUC_CONST;
-#define GDK_TYPE_EXTENSION_MODE (gdk_extension_mode_get_type ())
 GType gdk_input_source_get_type (void) G_GNUC_CONST;
 #define GDK_TYPE_INPUT_SOURCE (gdk_input_source_get_type ())
 GType gdk_input_mode_get_type (void) G_GNUC_CONST;
@@ -65,6 +63,8 @@ GType gdk_byte_order_get_type (void) G_GNUC_CONST;
 #define GDK_TYPE_BYTE_ORDER (gdk_byte_order_get_type ())
 GType gdk_modifier_type_get_type (void) G_GNUC_CONST;
 #define GDK_TYPE_MODIFIER_TYPE (gdk_modifier_type_get_type ())
+GType gdk_modifier_intent_get_type (void) G_GNUC_CONST;
+#define GDK_TYPE_MODIFIER_INTENT (gdk_modifier_intent_get_type ())
 GType gdk_status_get_type (void) G_GNUC_CONST;
 #define GDK_TYPE_STATUS (gdk_status_get_type ())
 GType gdk_grab_status_get_type (void) G_GNUC_CONST;
